@@ -265,18 +265,6 @@ class App(cmd2.Cmd):
 
         self.nucleus_driver.messages.write_message('Syslog path is set to: {}'.format(new_path))
 
-    list_syslog_parser = Cmd2ArgumentParser(description='List syslog entries')
-
-    @with_argparser(list_syslog_parser)
-    @with_category(CMD_CAT_SYSLOG)
-    def do_syslog_list_entries(self, _):
-
-        if not self.nucleus_driver.connection.get_connection_status():
-            self.nucleus_driver.messages.write_message('Nucleus not connected')
-            return
-
-        self.nucleus_driver.list_syslog()
-
     download_syslog_parser = Cmd2ArgumentParser(description='Download syslog')
 
     @with_argparser(download_syslog_parser)
@@ -314,7 +302,7 @@ class App(cmd2.Cmd):
 
     @with_argparser(set_download_path_parser)
     @with_category(CMD_CAT_DOWNLOAD)
-    def do_convert_nucleus_data(self, set_download_path_args):
+    def do_set_download_path(self, set_download_path_args):
 
         path = set_download_path_args.path
 
